<?php

namespace Emixion\Calendar\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Form;
use Emixion\Calendar\Http\Requests\EventsAdminRequest;
use Emixion\Calendar\Interfaces\EventsRepositoryInterface;
use Emixion\Calendar\Models\Events;

/**
 * Admin controller class.
 */
class EventsAdminController extends AdminController
{
    /**
     * Initialize events controller.
     *
     * @param type EventsRepositoryInterface $events
     *
     * @return type
     */
    public function __construct(EventsRepositoryInterface $events)
    {
        parent::__construct();
        $this->repository = $events;
    }

    /**
     * Display a list of events.
     *
     * @return Response
     */
    public function index(EventsAdminRequest $request)
    {
        $events  = $this->repository->setPresenter('\\Emixion\\Calendar\\Repositories\\Presenter\\EventsListPresenter')
                                            ->scopeQuery(function($query){
                                                return $query->orderBy('id','DESC');
                                            })->paginate();
        $this   ->theme->prependTitle(trans('calendar::events.names').' :: ');
        $view   = $this->theme->of('calendar::admin.events.index')->render();

        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('calendar::events.name')]);
        $this->responseData = $events['data'];
        $this->responseMeta = $events['meta'];
        $this->responseView = $view;
        $this->responseRedirect = '';
        return $this->respond($request);
    }

    /**
     * Display events.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(EventsAdminRequest $request, Events $events)
    {
        if (!$events->exists) {
            $this->responseCode = 404;
            $this->responseMessage = trans('messages.success.notfound', ['Module' => trans('calendar::events.name')]);
            $this->responseView = view('calendar::admin.events.new');
            return $this -> respond($request);
        }

        Form::populate($events);
        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('calendar::events.name')]);
        $this->responseData = $events;
        $this->responseView = view('calendar::admin.events.show', compact('events'));
        return $this -> respond($request);
    }

    /**
     * Show the form for creating a new events.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(EventsAdminRequest $request)
    {

        $events = $this->repository->newInstance([]);

        Form::populate($events);

        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('calendar::events.name')]);
        $this->responseData = $events;
        $this->responseView = view('calendar::admin.events.create', compact('events'));
        return $this -> respond($request);

    }

    /**
     * Create new events.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EventsAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $events = $this->repository->create($attributes);

            $this->responseCode = 201;
            $this->responseMessage = trans('messages.success.created', ['Module' => trans('calendar::events.name')]);
            $this->responseData = $events;
            $this->responseMeta = '';
            $this->responseRedirect = trans_url('/admin/calendar/events/'.$events->getRouteKey());
            $this->responseView = view('calendar::admin.events.create', compact('events'));

            return $this -> respond($request);

        } catch (Exception $e) {
            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            return $this -> respond($request);
        }
    }

    /**
     * Show events for editing.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(EventsAdminRequest $request, Events $events)
    {
        Form::populate($events);
        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('calendar::events.name')]);
        $this->responseData = $events;
        $this->responseView = view('calendar::admin.events.edit', compact('events'));

        return $this -> respond($request);
    }

    /**
     * Update the events.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(EventsAdminRequest $request, Events $events)
    {
        try {

            $attributes = $request->all();

            $events->update($attributes);

            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.updated', ['Module' => trans('calendar::events.name')]);
            $this->responseData = $events;
            $this->responseRedirect = trans_url('/admin/calendar/events/'.$events->getRouteKey());

            return $this -> respond($request);

        } catch (Exception $e) {

            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            $this->responseRedirect = trans_url('/admin/calendar/events/'.$events->getRouteKey());

            return $this -> respond($request);
        }
    }

    /**
     * Remove the events.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(EventsAdminRequest $request, Events $events)
    {

        try {

            $t = $events->delete();

            $this->responseCode = 202;
            $this->responseMessage = trans('messages.success.deleted', ['Module' => trans('calendar::events.name')]);
            $this->responseRedirect = trans_url('/admin/calendar/events/0');

            return $this -> respond($request);

        } catch (Exception $e) {

            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            $this->responseRedirect = trans_url('/admin/calendar/events/'.$events->getRouteKey());

            return $this -> respond($request);

        }
    }
}
